pynamelix
=========
API to `namelix.com <https://namelix.com>`__

Install
-------
From PyPi:

.. code-block:: bash

  pip install pynamelix

from source:

.. code-block:: bash

  git clone https://github.com/axju/pynamelix
  pip install .

Quick start
-----------
As a command line interface:

.. code-block:: bash

  python -m pynamelix -h

or:

.. code-block:: bash

  pynamelix -h

Example:

.. code-block:: bash

  python -m pynamelix -p -s wordmix -l medium python axju
